@@ -213,7 +213,6 @@ struct NautilusIconContainerDetails {
 	gboolean single_click_mode;
 	gboolean auto_layout;
 	gboolean tighter_layout;
-	gboolean active_background;
 
 	/* Whether for the vertical layout, all columns are supposed to
 	 * have the same width. */
@@ -272,7 +271,6 @@ struct NautilusIconContainerDetails {
 	time_t layout_timestamp;
 
 	/* interactive search */
-	gboolean disable_popdown;
 	gboolean imcontext_changed;
 	int selected_iter;
 	GtkWidget *search_window;
